@@ -57,6 +57,15 @@ function confirmDeleteCompany(elemID) {
     return true;
 }
 
+function confirmDeleteClause(elemID) {
+    if(!confirm("Do you really want to delete this Clause?")) {
+        return false;
+    }
+    var modeElem = document.getElementById(elemID);
+    modeElem.value = "deleteclause";
+    return true;
+}
+
 function confirmDeleteLine(elemID) {
     if(!confirm("Do you really want to delete this ProdLine?")) {
         return false;
